[![Build Status](https://travis-ci.com/rousuy/lib_pythonpro.svg?branch=main)](https://travis-ci.com/rousuy/lib_pythonpro)
[![Python 3](https://pyup.io/repos/github/rousuy/lib_pythonpro/python-3-shield.svg)](https://pyup.io/repos/github/rousuy/lib_pythonpro/)
[![Updates](https://pyup.io/repos/github/rousuy/lib_pythonpro/shield.svg)](https://pyup.io/repos/github/rousuy/lib_pythonpro/)

# lib_pythonpro

Repositório para exemplificar construção de projetos em Python

Link do curso: [Python Pro](https://pythonprobr.appspot.com/)

Suportada a versão 3 do Python

Tópicos a serem abordados:
  - Requirements
  - Flake8

### **Requirements**

Para Instalar:
###### console:
```
pip install -r requirements.txt
``` 

### **Flake8**

Para instalar:
###### console:
```
$ flake8
```


